==> deepin-session-ui-debug-6.0.21-4-x86_64.pkg.tar.zst: usr/src/debug/deepin-session-ui/dde-session-ui/dde-osd/dde-osd-shared_autogen/UVLADIE3JM/qrc_theme.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-session-ui/src/dde-session-ui/dde-osd/src/light.qss
  0x0,0x0,0x0,0x3d,
  0x51,
  0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,
  0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x74,0x72,0x61,0x6e,0x73,
  0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,
  0x65,0x72,0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // themes
  0x0,0x6,
  0x7,0xae,0xc3,0xc3,
  0x0,0x74,
  0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,0x0,0x73,
    // light.qss
  0x0,0x9,
  0xd,0xf7,0xbd,0x43,
  0x0,0x6c,
  0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,0x2e,0x0,0x71,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x56,0x5e,0x54,0xf8,
  // :/themes
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x56,0x5e,0x54,0xf8,
  // :/themes/light.qss
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x56,0x5e,0x54,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)(); }
   } dummy;
}

==> deepin-session-ui-debug-6.0.22-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-session-ui/dde-session-ui/dde-osd/dde-osd-shared_autogen/UVLADIE3JM/qrc_theme.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-session-ui/src/dde-session-ui/dde-osd/src/light.qss
  0x0,0x0,0x0,0x3d,
  0x51,
  0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,
  0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x74,0x72,0x61,0x6e,0x73,
  0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,
  0x65,0x72,0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // themes
  0x0,0x6,
  0x7,0xae,0xc3,0xc3,
  0x0,0x74,
  0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,0x0,0x73,
    // light.qss
  0x0,0x9,
  0xd,0xf7,0xbd,0x43,
  0x0,0x6c,
  0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,0x2e,0x0,0x71,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x77,0x41,0xd3,0x98,
  // :/themes
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x77,0x41,0xd3,0x98,
  // :/themes/light.qss
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x77,0x41,0xd3,0x98,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)(); }
   } dummy;
}
